==> ae_cdnz-0.3.1.tar.gz: ae_cdnz-0.3.1/README.md <==
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project ae.ae V0.3.94 -->
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project aedev.tpl_namespace_root V0.3.14 -->
# cdnz 0.3.1

[![GitLab develop](https://img.shields.io/gitlab/pipeline/ae-group/ae_cdnz/develop?logo=python)](
    https://gitlab.com/ae-group/ae_cdnz)
[![LatestPyPIrelease](
    https://img.shields.io/gitlab/pipeline/ae-group/ae_cdnz/release?logo=python)](
    https://gitlab.com/ae-group/ae_cdnz/-/tree/release)
[![PyPIVersions](https://img.shields.io/pypi/v/ae_cdnz)](
    https://pypi.org/project/ae-cdnz/#history)

>ae_cdnz module 0.3.1.

[![Coverage](https://ae-group.gitlab.io/ae_cdnz/coverage.svg)](
    https://ae-group.gitlab.io/ae_cdnz/coverage/index.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_cdnz/mypy.svg)](
    https://ae-group.gitlab.io/ae_cdnz/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_cdnz/pylint.svg)](
    https://ae-group.gitlab.io/ae_cdnz/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_cdnz)](
    https://gitlab.com/ae-group/ae_cdnz/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_cdnz)](
    https://gitlab.com/ae-group/ae_cdnz/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_cdnz)](
    https://gitlab.com/ae-group/ae_cdnz/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_cdnz)](
    https://pypi.org/project/ae-cdnz/)
[![PyPILicense](https://img.shields.io/pypi/l/ae_cdnz)](
    https://gitlab.com/ae-group/ae_cdnz/-/blob/develop/LICENSE.md)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_cdnz)](
    https://libraries.io/pypi/ae-cdnz)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_cdnz)](
    https://pypi.org/project/ae-cdnz/#files)


## installation


execute the following command to install the
ae.cdnz module
in the currently active virtual environment:
 
```shell script
pip install ae-cdnz
```

if you want to contribute to this portion then first fork
[the ae_cdnz repository at GitLab](
https://gitlab.com/ae-group/ae_cdnz "ae.cdnz code repository").
after that pull it to your machine and finally execute the
following command in the root folder of this repository
(ae_cdnz):

```shell script
pip install -e .[dev]
```

the last command will install this module portion, along with the tools you need
to develop and run tests or to extend the portion documentation. to contribute only to the unit tests or to the
documentation of this portion, replace the setup extras key `dev` in the above command with `tests` or `docs`
respectively.

more detailed explanations on how to contribute to this project
[are available here](
https://gitlab.com/ae-group/ae_cdnz/-/blob/develop/CONTRIBUTING.rst)


## namespace portion documentation

information on the features and usage of this portion are available at
[ReadTheDocs](
https://ae.readthedocs.io/en/latest/_autosummary/ae.cdnz.html
"ae_cdnz documentation").

==> ae_cdnz-0.3.2.tar.gz: ae_cdnz-0.3.2/README.md <==
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project ae.ae V0.3.94 -->
<!-- THIS FILE IS EXCLUSIVELY MAINTAINED by the project aedev.tpl_namespace_root V0.3.14 -->
# cdnz 0.3.2

[![GitLab develop](https://img.shields.io/gitlab/pipeline/ae-group/ae_cdnz/develop?logo=python)](
    https://gitlab.com/ae-group/ae_cdnz)
[![LatestPyPIrelease](
    https://img.shields.io/gitlab/pipeline/ae-group/ae_cdnz/release0.3.1?logo=python)](
    https://gitlab.com/ae-group/ae_cdnz/-/tree/release0.3.1)
[![PyPIVersions](https://img.shields.io/pypi/v/ae_cdnz)](
    https://pypi.org/project/ae-cdnz/#history)

>ae_cdnz module 0.3.2.

[![Coverage](https://ae-group.gitlab.io/ae_cdnz/coverage.svg)](
    https://ae-group.gitlab.io/ae_cdnz/coverage/index.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_cdnz/mypy.svg)](
    https://ae-group.gitlab.io/ae_cdnz/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_cdnz/pylint.svg)](
    https://ae-group.gitlab.io/ae_cdnz/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_cdnz)](
    https://gitlab.com/ae-group/ae_cdnz/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_cdnz)](
    https://gitlab.com/ae-group/ae_cdnz/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_cdnz)](
    https://gitlab.com/ae-group/ae_cdnz/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_cdnz)](
    https://pypi.org/project/ae-cdnz/)
[![PyPILicense](https://img.shields.io/pypi/l/ae_cdnz)](
    https://gitlab.com/ae-group/ae_cdnz/-/blob/develop/LICENSE.md)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_cdnz)](
    https://libraries.io/pypi/ae-cdnz)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_cdnz)](
    https://pypi.org/project/ae-cdnz/#files)


## installation


execute the following command to install the
ae.cdnz module
in the currently active virtual environment:
 
```shell script
pip install ae-cdnz
```

if you want to contribute to this portion then first fork
[the ae_cdnz repository at GitLab](
https://gitlab.com/ae-group/ae_cdnz "ae.cdnz code repository").
after that pull it to your machine and finally execute the
following command in the root folder of this repository
(ae_cdnz):

```shell script
pip install -e .[dev]
```

the last command will install this module portion, along with the tools you need
to develop and run tests or to extend the portion documentation. to contribute only to the unit tests or to the
documentation of this portion, replace the setup extras key `dev` in the above command with `tests` or `docs`
respectively.

more detailed explanations on how to contribute to this project
[are available here](
https://gitlab.com/ae-group/ae_cdnz/-/blob/develop/CONTRIBUTING.rst)


## namespace portion documentation

information on the features and usage of this portion are available at
[ReadTheDocs](
https://ae.readthedocs.io/en/latest/_autosummary/ae.cdnz.html
"ae_cdnz documentation").
